@@ -432,7 +432,7 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
   for (size_t i=0; i<Sudoku::dimension*Sudoku::dimension; i++) {
 
     // Draw background
-    if ((HasFocus() || Lum::OS::display->GetTheme()->RequestFingerFriendlyControls())
+    if ((HasFocus() || true/*Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()*/)
         && !finished->Get() && i==focusedCell) {
       draw->PushForeground(focusBackgroundColor);
     }
@@ -558,7 +558,7 @@ bool GameArea::HandleMouseEvent(const Lum::OS::MouseEvent& event)
         return true;
       }
 
-      if (Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+      if (true/*Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()*/) {
         // No popup dialog, if we need to be finger friendly!
         // We will make use of an external keypad instead in this case.
         return true;
