@@ -289,14 +289,16 @@ public:
       ->Group(_(L"MENU_GAME",L"_Game"))
         ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_NEW",L"_Generate new game"))
                                   .SetShortcut(Lum::OS::qualifierControl,L"g"),
-                                  generateAction))
+                                  generateAction)
+                 .SetOpensDialog())
         ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_SOLVE",L"_Solve game"))
                                   .SetShortcut(Lum::OS::qualifierControl,L"s"),
                                   solveAction))
         ->Separator()
         ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_STAT",L"S_tatistics"))
                                   .SetShortcut(Lum::OS::qualifierControl,L"t"),
-                                  statAction))
+                                  statAction)
+                 .SetOpensDialog())
       ->End()
       ->GroupHelp()
         ->ActionHelp(helpAction)
